=======
History
=======

0.1.1 (2016-3-3)
------------------

* Add method to create resource.
* Add examples on how to create contacts, products and sales.

0.1.0 (2016-1-22)
------------------

* First release on PyPI.
